# Choicer

<b>Ever had a problem with making decisions?</b>
Wanted to flip a coin for it? Maybe once, maybe twice, maybe a 100 times, maybe 10,000 times, just to be sure?
Don't worry, we are here for you. No matter how many choies, no matter how many times you want to count.

We will help you make your decision.

Simple syntax:
choose num_times option1 option2 [...options]
